@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  textcopy.rb - a TEXTCOPY compatible Saori module for ninix
-#  Copyright (C) 2002-2016 by Shyouzou Sugitani <shy@users.osdn.me>
+#  Copyright (C) 2002-2017 by Shyouzou Sugitani <shy@users.osdn.me>
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -22,18 +22,18 @@ module Textcopy
   class Saori < DLL::SAORI
 
     def initialize
-      super()
+      super
       @clipboard = nil
     end
 
     def setup
       @clipboard = Gtk::Clipboard.get('PRIMARY')
-      return 1
+      1
     end
 
     def finalize
       @clipboard = nil
-      return 1
+      1
     end
 
     def execute(argument)
