@@ -2,7 +2,7 @@
 #
 #  yaya.rb - a (Real) YAYA loader for ninix
 #  Copyright (C) 2004 by linjian
-#  Copyright (C) 2004-2016 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2004-2017 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2011 by henryhu
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -51,14 +51,14 @@ module Yaya
           result = 105
         end
       end
-      return result
+      result
     end
 
     def show_description
       Logging::Logging.info(
         "Shiori: a (Real) YAYA loader for ninix\n" \
         "        Copyright (C) 2004 by linjian\n" \
-        "        Copyright (C) 2004-2016 by Shyouzou Sugitani\n" \
+        "        Copyright (C) 2004-2017 by Shyouzou Sugitani\n" \
         "        Copyright (C) 2011 by henryhu")
     end
 
@@ -76,8 +76,7 @@ module Yaya
       )
       path[0, @dir.bytesize] = @dir
       @id = $_yaya.multi_load(path, @dir.bytesize)
-      ret = 1
-      return ret
+      1
     end
 
     def unload
@@ -95,7 +94,7 @@ module Yaya
       rlen =[req_string.bytesize].pack("l!")
       ret = $_yaya.multi_request(@id, request, rlen)
       rlen, = rlen.unpack("l!")
-      return ret[0, rlen].to_s
+      ret[0, rlen].to_s
     end
   end
 end
